clear
use "/Users/Marina/Dropbox/FINISHED/Network Bargaining Experiement/Experiments/DataAnalysis/Structured_2015/Analysis/data_original.dta"

***********************
**    VARIABLES      **
***********************

gen finalpayoff = potentialpayoff if matchending!=. & matchending!=2 

** Variables for unique session, unique id and unique game-group id
gen sessionun = game*100+separation*10 + session*1
gen uniqueid = sessionun*100+clientid

** Efficiency of Final Match

sort sessionun match group round index
gen     totalpayoff = finalpayoff[_n]+finalpayoff[_n+1]+finalpayoff[_n+2]+finalpayoff[_n+3] if matchending!=. & matchending!=2 & index==0

gen     temp = 1 if separation==0 & totalpayoff==40 & matchending!=. & matchending!=2 & index==0
replace temp = 0 if separation==0 & totalpayoff<40 & totalpayoff>0 & matchending!=. & matchending!=2 & index==0
replace temp = 1 if separation==1 & totalpayoff>=37.1 & totalpayoff<=40 & matchending!=. & matchending!=2 & index==0
replace temp = 0 if separation==1 & totalpayoff<37.1 & totalpayoff>0 & matchending!=. & matchending!=2 & index==0

bysort sessionun match groupid: egen efficient = max(temp)
drop temp

** sum of strong players' payoffs
sort sessionun match group round index
gen  sumstrongpayoffs = finalpayoff[_n+1]+finalpayoff[_n+3] if matchending!=. & matchending!=2 & index==0

** dummies for each game
gen game15 = (game==15)
gen game25 = (game==25)
gen game30 = (game==30)

** network position 
gen strong = (index==1 | index==3)

** variable that keeps track of who is matched and who is not
gen matched = (roundpotentialpayoff!=.)
replace matched = . if roundpotentialpayoff==0 & (matchending==1 | matchending==2 | matchending==3)

** variable that takes value 1 if all players are unmatched
sort sessionun match groupid round index
gen     allnotmatched = 1 if round==0
replace allnotmatched = 1 if round>=1 & index==0 & matched[_n-4]==0 & matched[_n-3]==0  & matched[_n-2]==0 & matched[_n-1]==0 
replace allnotmatched = 1 if round>=1 & index==1 & matched[_n-5]==0 & matched[_n-4]==0  & matched[_n-3]==0 & matched[_n-2]==0 
replace allnotmatched = 1 if round>=1 & index==2 & matched[_n-6]==0 & matched[_n-5]==0  & matched[_n-4]==0 & matched[_n-3]==0 
replace allnotmatched = 1 if round>=1 & index==3 & matched[_n-7]==0 & matched[_n-6]==0  & matched[_n-5]==0 & matched[_n-4]==0 
replace allnotmatched = 0 if round>=1 & allnotmatched==.

** responder's amount in the selected offer
gen     responderamounttemp = 20-proposeamount if responder==3 & selectedproposer==0 & selectedproposer==index 
replace responderamounttemp = 20-proposeamount if responder==0 & selectedproposer==3 & selectedproposer==index 
replace responderamounttemp = 20-proposeamount if responder==2 & selectedproposer==1 & selectedproposer==index 
replace responderamounttemp = 20-proposeamount if responder==1 & selectedproposer==2 & selectedproposer==index 
replace responderamounttemp = 30-proposeamount if responder==1 & selectedproposer==3 & selectedproposer==index  & game==30
replace responderamounttemp = 30-proposeamount if responder==3 & selectedproposer==1 & selectedproposer==index  & game==30
replace responderamounttemp = 25-proposeamount if responder==1 & selectedproposer==3 & selectedproposer==index  & game==25
replace responderamounttemp = 25-proposeamount if responder==3 & selectedproposer==1 & selectedproposer==index  & game==25
replace responderamounttemp = 15-proposeamount if responder==1 & selectedproposer==3 & selectedproposer==index  & game==15
replace responderamounttemp = 15-proposeamount if responder==3 & selectedproposer==1 & selectedproposer==index  & game==15

bysort sessionun match groupid round: egen responderamount = max(responderamounttemp)
drop responderamounttemp



** TABLE 1

** Regression (1)
reg efficient game25 game30 if separation==0 & matchend!=. & matchend!=2 & index==0 & match>4, cluster(sessionun)
test game25 game30
test game30 = game25
test _cons + game25 = 0.72
test _cons + game30 = 0.50

reg efficient game30 if separation==0 & matchend!=. & matchend!=2 & index==0 & match>4 & game!=15, cluster(sessionun)



** Regression (2)
gen     firstmoverweaktemp = 1 if round==0 & (selectedproposer==0 | selectedproposer==2)
replace firstmoverweaktemp = 0 if round==0 & (selectedproposer==1 | selectedproposer==3)

bysort sessionun match groupid: egen firstmoverweak = max(firstmoverweaktemp)
drop firstmoverweaktemp

gen firstmoverstrong = (firstmoverweak==0)
gen firstmoverstrong15 = (firstmoverstrong==1 & game==15)
gen firstmoverstrong25 = (firstmoverstrong==1 & game==25)
gen firstmoverstrong30 = (firstmoverstrong==1 & game==30)

reg efficient firstmoverstrong15  game25 firstmoverstrong25 game30 firstmoverstrong30 if separation==0 & matchend!=. & matchend!=2 & index==0 & match>4, cluster(sessionun)
test firstmoverstrong25 = 0
test firstmoverstrong30 = 0
test game30 + firstmoverstrong30 = game25 + firstmoverstrong25


reg efficient  firstmoverstrong25 game30 firstmoverstrong30 if game!=15 & separation==0 & matchend!=. & matchend!=2 & index==0 & match>4, cluster(sessionun)

** Regression (3)
gen strong15 = (game==15 & strong==1)
gen strong25 = (game==25 & strong==1)
gen strong30 = (game==30 & strong==1)
 
reg finalpayoff strong15 game25 strong25 game30 strong30 if separation==0 & matchend!=. & matchend!=2  & match>4, cluster(sessionun)
test strong15 = 0
test strong25 = 0
test strong30 = 0

test strong15 = game25 + strong25
test strong30 + game30 = game25 + strong25

test 0 = game25  
test  game30 = game25 

test _cons+game25=5
test _cons+game30=5


reg finalpayoff strong25 game30 strong30 if game!=15 & separation==0 & matchend!=. & matchend!=2  & match>4, cluster(sessionun)


** Regression (4)
** who exited first in the no separation treatment
gen exitfirsttemp = 1 if roundpotentialpayoff!=. & matchend==.
replace exitfirsttemp = 0 if roundpotentialpayoff==. & matchend==.
bysort sessionun match groupid index: egen exitfirst = max(exitfirsttemp)
drop exitfirsttemp

gen exitfirst15 = (exitfirst==1 & game==15)
gen exitfirst25 = (exitfirst==1 & game==25)
gen exitfirst30 = (exitfirst==1 & game==30)

reg finalpayoff exitfirst15 game25 exitfirst25 game30 exitfirst30 if separation==0 & matchend!=. & matchend!=2 & match>4 & strong==1 & efficient==1, cluster(sessionun)
test exitfirst15 = 0
test exitfirst25 = 0
test exitfirst30 = 0
test exitfirst15 = exitfirst25
test exitfirst25 = exitfirst30

** Efficiency comparison between Experiment I and Experiment III

gen exp3game15 = game15 * separation
gen exp3game25 = game25 * separation
gen exp3game30 = game30 * separation

reg efficient  game25 game30 exp3game15 exp3game25 exp3game30 if matchend!=. & matchend!=2 & match>4 & index==0, cluster(sessionun)
test const + game25 + exp3game25 = 1
test const + game30 + exp3game30 = 1

** Payoffs comparisons between Experiment I and Experiment III

reg finalpayoff game25 game30 exp3game15 exp3game25 exp3game30 if matchend!=. & matchend!=2 & match>4 & strong==0, cluster(sessionun)
reg finalpayoff game25 game30 exp3game15 exp3game25 exp3game30 if matchend!=. & matchend!=2 & match>4 & strong==1, cluster(sessionun)
reg finalpayoff game25 game30 exp3game15 exp3game25 exp3game30 if matchend!=. & matchend!=2 & match>4 & strong==1 & efficient==1, cluster(sessionun)
reg finalpayoff game25 game30 exp3game15 exp3game25 exp3game30 if matchend!=. & matchend!=2 & match>4 & strong==0 & efficient==1, cluster(sessionun)

** average payoffs of players in efficient outcomes

reg finalpayoff if strong==0 & game==25 & separation==0 & match>4 & efficient==1 & matchend!=. & matchend!=2, cluster(sessionun)
reg finalpayoff if strong==0 & game==30 & separation==0 & match>4 & efficient==1 & matchend!=. & matchend!=2, cluster(sessionun)

** who made first accepted offer?
gen     firstacceptedmoveweaktemp = 1 if separation==0 & round==0 & (selectedproposer==0 | selectedproposer==2) & respondermove==1
replace firstacceptedmoveweaktemp = 0 if separation==0 & round==0 & (selectedproposer==1 | selectedproposer==3) & respondermove==1
 
replace firstacceptedmoveweaktemp = 1 if separation==0 & round==1 & (selectedproposer==0 | selectedproposer==2) & respondermove==1 & allnotmatched==1
replace firstacceptedmoveweaktemp = 0 if separation==0 & round==1 & (selectedproposer==1 | selectedproposer==3) & respondermove==1 & allnotmatched==1

replace firstacceptedmoveweaktemp = 1 if separation==0 & round==2 & (selectedproposer==0 | selectedproposer==2) & respondermove==1 & allnotmatched==1
replace firstacceptedmoveweaktemp = 0 if separation==0 & round==2 & (selectedproposer==1 | selectedproposer==3) & respondermove==1 & allnotmatched==1

replace firstacceptedmoveweaktemp = 1 if separation==0 & round==3 & (selectedproposer==0 | selectedproposer==2) & respondermove==1 & allnotmatched==1
replace firstacceptedmoveweaktemp = 0 if separation==0 & round==3 & (selectedproposer==1 | selectedproposer==3) & respondermove==1 & allnotmatched==1

replace firstacceptedmoveweaktemp = 1 if separation==0 & round==4 & (selectedproposer==0 | selectedproposer==2) & respondermove==1 & allnotmatched==1
replace firstacceptedmoveweaktemp = 0 if separation==0 & round==4 & (selectedproposer==1 | selectedproposer==3) & respondermove==1 & allnotmatched==1

replace firstacceptedmoveweaktemp = 1 if separation==0 & round==5 & (selectedproposer==0 | selectedproposer==2) & respondermove==1 & allnotmatched==1
replace firstacceptedmoveweaktemp = 0 if separation==0 & round==5 & (selectedproposer==1 | selectedproposer==3) & respondermove==1 & allnotmatched==1

replace firstacceptedmoveweaktemp = 1 if separation==0 & round==6 & (selectedproposer==0 | selectedproposer==2) & respondermove==1 & allnotmatched==1
replace firstacceptedmoveweaktemp = 0 if separation==0 & round==6 & (selectedproposer==1 | selectedproposer==3) & respondermove==1 & allnotmatched==1

replace firstacceptedmoveweaktemp = 1 if separation==0 & round==7 & (selectedproposer==0 | selectedproposer==2) & respondermove==1 & allnotmatched==1
replace firstacceptedmoveweaktemp = 0 if separation==0 & round==7 & (selectedproposer==1 | selectedproposer==3) & respondermove==1 & allnotmatched==1

replace firstacceptedmoveweaktemp = 1 if separation==0 & round==8 & (selectedproposer==0 | selectedproposer==2) & respondermove==1 & allnotmatched==1
replace firstacceptedmoveweaktemp = 0 if separation==0 & round==8 & (selectedproposer==1 | selectedproposer==3) & respondermove==1 & allnotmatched==1


bysort sessionun match groupid: egen firstacceptedmoveweak = max(firstaccepted)
drop firstacceptedmoveweaktemp

gen firstacceptedmovestrong = (firstacceptedmoveweak==0)

gen firstacceptedmoveweak15 = (firstacceptedmoveweak==1 & game==15)
gen firstacceptedmoveweak25 = (firstacceptedmoveweak==1 & game==25)
gen firstacceptedmoveweak30 = (firstacceptedmoveweak==1 & game==30)

reg efficient  game25 firstacceptedmoveweak25 game30 firstacceptedmoveweak30 if separation==0 & matchend!=. & matchend!=2 & index==0 & match>4, cluster(sessionun)
test firstacceptedmoveweak25 = 0
test firstacceptedmoveweak30 = 0
test _cons + game30 + firstacceptedmoveweak30 = _cons + game25 + firstacceptedmoveweak25



****************************************
*** PLAYERS' STRATEGIES EXPERIMENT I ***
****************************************

** payoffs when only two players are active

reg finalpayoff game25 game30 strong15 strong25 strong30 if separation==0 & matchend!=. & matchend!=2 & match>4 & exitfirst==0  & efficient==1, cluster(sessionun)
test strong15 = 0
test strong25 = 0
test strong30 = 0


** frequency of delays by weak and strong players

gen delay = (proposeto==-1)
tab delay game if matchend!=. & matchend!=2 & match>=5  & separation==0 & allnotmatched==1

reg delay game30 strong25 strong30 if  matchend!=. & matchend!=2 & match>=5  & separation==0 & allnotmatched==1 & game!=15, cluster(sessionun)
test strong25 = 0
test strong30 = 0


** how often strong players propose efficiently


** Players strategies for strong players

** frequency with which strong players propose efficient match in the last 5 games taking into account the length of the game
**********************************************************************************************************************************
gen     action = 1  if index==1 & proposeto==2 & match>=5
replace action = 0  if index==1 & proposeto==3 & match>=5
replace action = -1 if index==1 & proposeto==-1  & match>=5
replace action = 1  if index==3 & proposeto==0 & match>=5
replace action = 0  if index==3 & proposeto==1 & match>=5
replace action = -1 if index==3 & proposeto==-1  & match>=5

replace action = 1  if index==0 & proposeto==3  & match>=5
replace action = -1 if index==0 & proposeto==-1 & match>=5
replace action = 1  if index==2 & proposeto==1  & match>=5
replace action = -1 if index==2 & proposeto==-1 & match>=5


gen     t = 1 if separation==0 & allnotmatched==1 & (index==1 | index==3) & action==1 & match>=5
replace t = 0 if separation==0 & allnotmatched==1 & (index==1 | index==3) & action==0 & match>=5
replace t = 1 if separation==1 & (index==1 | index==3) & action==1 & match>=5
replace t = 0 if separation==1 & (index==1 | index==3) & action==0 & match>=5

gen     s = 1 if separation==0 & allnotmatched==1 & (index==1 | index==3) & action!=-1 & match>=5
replace s = 0 if separation==0 & allnotmatched==1 & (index==1 | index==3) & action==-1 & match>=5
replace s = 1 if separation==1 & (index==1 | index==3) & action!=-1 & match>=5
replace s = 0 if separation==1 & (index==1 | index==3) & action==-1 & match>=5

sort separation game uniqueid round
by separation game uniqueid: egen tt = sum(t) 
by separation game uniqueid: egen ss = sum(s) 
by separation game uniqueid: gen fraceff = tt/ss

reg fraceff game25 game30 if separation==0 & match>=5 & round==0 & allnotmatched==1 & (index==1 | index==3), cluster(sessionun)
test game25 = game30


** efficiency comparison between Experiment I and Experiment III
reg efficie separation if match>=5 & game==30  & matchend!=. & matchend!=2 , cluster(sessionun)



********************************************
**** GENERAL STATISTICS EXPERIMENT I     ***
********************************************


reg efficient if matchend!=. & matchend!=2 & match>4 & index==2 & game==15 & separation==0, cluster(sessionun)
reg efficient if matchend!=. & matchend!=2 & match>4 & index==2 & game==25 & separation==0, cluster(sessionun)
reg efficient if matchend!=. & matchend!=2 & match>4 & index==2 & game==30 & separation==0, cluster(sessionun)

reg finalpayoff if matchend!=. & matchend!=2 & match>4 & strong==0 & game==15 & separation==0, cluster(sessionun)
reg finalpayoff if matchend!=. & matchend!=2 & match>4 & strong==1 & game==15 & separation==0, cluster(sessionun)
reg finalpayoff if matchend!=. & matchend!=2 & match>4 & strong==0 & game==25 & separation==0, cluster(sessionun)
reg finalpayoff if matchend!=. & matchend!=2 & match>4 & strong==1 & game==25 & separation==0, cluster(sessionun)
reg finalpayoff if matchend!=. & matchend!=2 & match>4 & strong==0 & game==30 & separation==0, cluster(sessionun)
reg finalpayoff if matchend!=. & matchend!=2 & match>4 & strong==1 & game==30 & separation==0, cluster(sessionun)

reg finalpayoff if matchend!=. & matchend!=2 & match>4 & strong==0 & game==15 & separation==0 & efficient==1, cluster(sessionun)
reg finalpayoff if matchend!=. & matchend!=2 & match>4 & strong==1 & game==15 & separation==0 & efficient==1, cluster(sessionun)
reg finalpayoff if matchend!=. & matchend!=2 & match>4 & strong==0 & game==25 & separation==0 & efficient==1, cluster(sessionun)
reg finalpayoff if matchend!=. & matchend!=2 & match>4 & strong==1 & game==25 & separation==0 & efficient==1, cluster(sessionun)
reg finalpayoff if matchend!=. & matchend!=2 & match>4 & strong==0 & game==30 & separation==0 & efficient==1, cluster(sessionun)
reg finalpayoff if matchend!=. & matchend!=2 & match>4 & strong==1 & game==30 & separation==0 & efficient==1, cluster(sessionun)


********************************************
**** GENERAL STATISTICS EXPERIMENT III     ***
********************************************


reg efficient if matchend!=. & matchend!=2 & match>4 & index==2 & game==15 & separation==1, cluster(sessionun)
reg efficient if matchend!=. & matchend!=2 & match>4 & index==2 & game==25 & separation==1, cluster(sessionun)
reg efficient if matchend!=. & matchend!=2 & match>4 & index==2 & game==30 & separation==1, cluster(sessionun)

reg finalpayoff if matchend!=. & matchend!=2 & match>4 & strong==0 & game==15 & separation==1, cluster(sessionun)
reg finalpayoff if matchend!=. & matchend!=2 & match>4 & strong==1 & game==15 & separation==1, cluster(sessionun)
reg finalpayoff if matchend!=. & matchend!=2 & match>4 & strong==0 & game==25 & separation==1, cluster(sessionun)
reg finalpayoff if matchend!=. & matchend!=2 & match>4 & strong==1 & game==25 & separation==1, cluster(sessionun)
reg finalpayoff if matchend!=. & matchend!=2 & match>4 & strong==0 & game==30 & separation==1, cluster(sessionun)
reg finalpayoff if matchend!=. & matchend!=2 & match>4 & strong==1 & game==30 & separation==1, cluster(sessionun)

reg finalpayoff if matchend!=. & matchend!=2 & match>4 & strong==0 & game==15 & separation==1 & efficient==1, cluster(sessionun)
reg finalpayoff if matchend!=. & matchend!=2 & match>4 & strong==1 & game==15 & separation==1 & efficient==1, cluster(sessionun)
reg finalpayoff if matchend!=. & matchend!=2 & match>4 & strong==0 & game==25 & separation==1 & efficient==1, cluster(sessionun)
reg finalpayoff if matchend!=. & matchend!=2 & match>4 & strong==1 & game==25 & separation==1 & efficient==1, cluster(sessionun)
reg finalpayoff if matchend!=. & matchend!=2 & match>4 & strong==0 & game==30 & separation==1 & efficient==1, cluster(sessionun)
reg finalpayoff if matchend!=. & matchend!=2 & match>4 & strong==1 & game==30 & separation==1 & efficient==1, cluster(sessionun)


** Box Graphs of proposed amounts
********************************

gen part = 1 if match<=4 
replace part = 2 if match>4

gen     strongtoweak = 1 if index==1 & proposeto==2
replace strongtoweak = 1 if index==3 & proposeto==0
replace strongtoweak = 0 if index==1 & proposeto==3
replace strongtoweak = 0 if index==3 & proposeto==1

gen     strongtostrong = 1 if index==1 & proposeto==3
replace strongtostrong = 1 if index==3 & proposeto==1
replace strongtostrong = 0 if index==1 & proposeto==2
replace strongtostrong = 0 if index==3 & proposeto==0

gen     weaktostrong = 1 if index==0 & proposeto==3
replace weaktostrong = 1 if index==2 & proposeto==1
replace weaktostrong = 0 if index==1
replace weaktostrong = 0 if index==3 

gen part2 = (part==2)


** TABLE 12
reg proposeamount if game==15 & strong==0 & proposeto!=-1 & match>4 & allnotmatched==1 & weaktostrong==1 & separation==0, cluster(sessionun)
reg proposeamount if game==15 & strong==1 & proposeto!=-1 & match>4 & allnotmatched==1 & strongtoweak==1 & separation==0, cluster(sessionun)

reg proposeamount if game==25 & strong==0 & proposeto!=-1 & match>4 & allnotmatched==1 & weaktostrong==1 & separation==0, cluster(sessionun)
reg proposeamount if game==25 & strong==1 & proposeto!=-1 & match>4 & allnotmatched==1 & strongtoweak==1 & separation==0, cluster(sessionun)
reg proposeamount if game==25 & strong==1 & proposeto!=-1 & match>4 & allnotmatched==1 & strongtostrong==1 & separation==0, cluster(sessionun)

reg proposeamount if game==30 & strong==0 & proposeto!=-1 & match>4 & allnotmatched==1 & weaktostrong==1 & separation==0, cluster(sessionun)
reg proposeamount if game==30 & strong==1 & proposeto!=-1 & match>4 & allnotmatched==1 & strongtoweak==1 & separation==0, cluster(sessionun)
reg proposeamount if game==30 & strong==1 & proposeto!=-1 & match>4 & allnotmatched==1 & strongtostrong==1 & separation==0, cluster(sessionun)


** game 25 - strong to weak

gen     game25askdiffSW = proposeamount - 13.55 if proposeamount>=13.55 & game==25 & strong==1 & proposeto!=-1 & allnotmatched==1 & strongtoweak==1
replace game25askdiffSW = 13.55 - proposeamount if proposeamount<13.55  & game==25 & strong==1 & proposeto!=-1 & allnotmatched==1 & strongtoweak==1

sort game separation part unique 
by   game separation part unique: egen game25avaskdiffSW = mean(game25askdiffSW)    if allnotmatched==1 & game==25 & separation==0 & strong==1 & strongtoweak==1 

xtreg game25askdiffSW part2 if game==25 & separation==0 & strong==1 & proposeto!=-1 & strongtoweak==1, i(sessionun) re
xtreg game25askdiffSW part2 if game==25 & separation==0 & strong==1 & proposeto!=-1 & strongtoweak==1, i(unique) re



** game 25 - strong to strong

gen     game25askdiffSS = proposeamount - 13.55 if proposeamount>=13.55 & game==25 & strong==1 & proposeto!=-1 & allnotmatched==1 & strongtostrong==1
replace game25askdiffSS = 13.55 - proposeamount if proposeamount<13.55  & game==25 & strong==1 & proposeto!=-1 & allnotmatched==1 & strongtostrong==1

sort game separation part unique 
by   game separation part unique: egen game25avaskdiffSS = mean(game25askdiffSS)    if allnotmatched==1 & game==25 & separation==0 & strong==1 & strongtostrong==1 

xtreg game25askdiffSS part2 if game==25 & separation==0 & strong==1 & proposeto!=-1 & strongtostrong==1, i(sessionun) re
xtreg game25askdiffSS part2 if game==25 & separation==0 & strong==1 & proposeto!=-1 & strongtostrong==1, i(unique) re



** game 25 - weak to strong

gen     game25askdiffWS = proposeamount - 8.55 if proposeamount>=8.55 & game==25 & strong==0 & proposeto!=-1 & allnotmatched==1 & weaktostrong==1
replace game25askdiffWS = 8.55 - proposeamount if proposeamount<8.55  & game==25 & strong==0 & proposeto!=-1 & allnotmatched==1 & weaktostrong==1

sort game separation part unique 
by   game separation part unique: egen game25avaskdiffWS = mean(game25askdiffWS)    if allnotmatched==1 & game==25 & separation==0 & strong==0 & weaktostrong==1 

xtreg game25askdiffWS part2 if game==25 & separation==0 & strong==0 & proposeto!=-1, i(sessionun) re
xtreg game25askdiffWS part2 if game==25 & separation==0 & strong==0 & proposeto!=-1, i(unique) re


** game 30 - strong to strong

gen     game30askdiffSS = proposeamount - 15.83 if proposeamount>=15.83 & game==30 & strong==1 & proposeto!=-1 & allnotmatched==1 & strongtostrong==1
replace game30askdiffSS = 15.83  - proposeamount if proposeamount<15.83   & game==30 & strong==1 & proposeto!=-1 & allnotmatched==1 & strongtostrong==1

sort game separation part unique 
by   game separation part unique: egen game30avaskdiffSS = mean(game30askdiffSS)    if allnotmatched==1 & game==30 & separation==0 & strong==1 & strongtostrong==1 

xtreg game30askdiffSS part if game==30 & separation==0 & strong==1 & proposeto!=-1 & strongtostrong==1, i(sessionun) re
xtreg game30askdiffSS part if game==30 & separation==0 & strong==1 & proposeto!=-1 & strongtostrong==1, i(unique) re


** game 30 - weak to strong
gen     game30askdiffWS = proposeamount - 6.67 if proposeamount>=6.67 & game==30 & strong==0 & proposeto!=-1 & allnotmatched==1 & weaktostrong==1
replace game30askdiffWS = 6.67- proposeamount if proposeamount<6.67  & game==30 & strong==0 & proposeto!=-1 & allnotmatched==1 & weaktostrong==1

sort game separation part unique 
by   game separation part unique: egen game30avaskdiffWS = mean(game30askdiffWS)    if allnotmatched==1 & game==30 & separation==0 & strong==0 & weaktostrong==1 

xtreg game30askdiffWS part if game==30 & separation==0 & strong==0 & proposeto!=-1, i(sessionun) re
xtreg game30askdiffWS part if game==30 & separation==0 & strong==0 & proposeto!=-1, i(unique) re

** all the graphs

graph box game25avaskdiffSW if allnotmatched==1 & game==25 & separation==0 & strong==1 & strongtoweak==1 , over(part)
graph box game25avaskdiffSS if allnotmatched==1 & game==25 & separation==0 & strong==1 & strongtostrong==1 , over(part)
graph box game25avaskdiffWS if allnotmatched==1 & game==25 & separation==0 & strong==0 & weaktostrong==1 , over(part)

graph box game30avaskdiffSS if allnotmatched==1 & game==30 & separation==0 & strong==1 & strongtostrong==1 , over(part)
graph box game30avaskdiffWS if allnotmatched==1 & game==30 & separation==0 & strong==0 & weaktostrong==1 , over(part)


** table with ask amount statistics
reg proposeamount if game==15  & separation==0 & proposeto!=-1 & allnotmatched==1& strong==1 & strongtowea==1 & part2==1, cluster(sessionun)
reg proposeamount if game==15  & separation==0 & proposeto!=-1 & allnotmatched==1& strong==0 & weaktostrong==1 & part2==1, cluster(sessionun)

reg proposeamount if game==25  & separation==0 & proposeto!=-1 & allnotmatched==1& strong==1 & strongtowea==1 & part2==1, cluster(sessionun)
reg proposeamount if game==25  & separation==0 & proposeto!=-1 & allnotmatched==1& strong==1 & strongtostrong==1 & part2==1, cluster(sessionun)
reg proposeamount if game==25  & separation==0 & proposeto!=-1 & allnotmatched==1& strong==0 & weaktostrong==1 & part2==1, cluster(sessionun)

reg proposeamount if game==30  & separation==0 & proposeto!=-1 & allnotmatched==1& strong==1 & strongtowea==1 & part2==1, cluster(sessionun)
reg proposeamount if game==30  & separation==0 & proposeto!=-1 & allnotmatched==1& strong==1 & strongtostrong==1 & part2==1, cluster(sessionun)
reg proposeamount if game==30  & separation==0 & proposeto!=-1 & allnotmatched==1& strong==0 & weaktostrong==1 & part2==1, cluster(sessionun)





******************************************
*****     SUPPLEMENTARY APPENDIX     *****
******************************************


************ COMPARING SUBJECT POOLS *****

gen     uci = 1 if session==4 & game==25 & separation==0
replace uci = 1 if session==4 & game==25 & separation==1
replace uci = 0 if session!=4 & game==25
 

reg efficient if separation==0 & game==25 & uci==0 & matchend!=. & matchend!=2 & index==0 & match<=4, cluster(sessionun)
reg efficient if separation==0 & game==25 & uci==1 & matchend!=. & matchend!=2 & index==0 & match<=4 
reg efficient if separation==0 & game==25 & uci==0 & matchend!=. & matchend!=2 & index==0 & match>4, cluster(sessionun)
reg efficient if separation==0 & game==25 & uci==1 & matchend!=. & matchend!=2 & index==0 & match>4 

reg efficient if separation==1 & game==25 & uci==0 & matchend!=. & matchend!=2 & index==0 & match<=4, cluster(sessionun)
reg efficient if separation==1 & game==25 & uci==1 & matchend!=. & matchend!=2 & index==0 & match<=4 
reg efficient if separation==1 & game==25 & uci==0 & matchend!=. & matchend!=2 & index==0 & match>4, cluster(sessionun)
reg efficient if separation==1 & game==25 & uci==1 & matchend!=. & matchend!=2 & index==0 & match>4 

reg efficient uci if separation==0 & game==25 & matchend!=. & matchend!=2 & index==0 & match<=4, cluster(sessionun)
reg efficient uci if separation==1 & game==25 & matchend!=. & matchend!=2 & index==0 & match<=4, cluster(sessionun)
reg efficient uci if separation==0 & game==25 & matchend!=. & matchend!=2 & index==0 & match>4, cluster(sessionun)
reg efficient uci if separation==1 & game==25 & matchend!=. & matchend!=2 & index==0 & match>4, cluster(sessionun)
 
 
 
reg finalpayoff if strong==1 & separation==0 & game==25 & uci==0 & matchend!=. & matchend!=2 & match<=4, cluster(sessionun)
reg finalpayoff if strong==1 & separation==0 & game==25 & uci==1 & matchend!=. & matchend!=2  & match<=4 
reg finalpayoff if strong==1 & separation==0 & game==25 & uci==0 & matchend!=. & matchend!=2   & match>4, cluster(sessionun)
reg finalpayoff if strong==1 & separation==0 & game==25 & uci==1 & matchend!=. & matchend!=2  & match>4 

reg finalpayoff if strong==0 & separation==0 & game==25 & uci==0 & matchend!=. & matchend!=2   & match<=4, cluster(sessionun)
reg finalpayoff if strong==0 & separation==0 & game==25 & uci==1 & matchend!=. & matchend!=2  & match<=4 
reg finalpayoff if strong==0 & separation==0 & game==25 & uci==0 & matchend!=. & matchend!=2  & match>4, cluster(sessionun)
reg finalpayoff if strong==0 & separation==0 & game==25 & uci==1 & matchend!=. & matchend!=2   & match>4 


reg finalpayoff if strong==1 & separation==1 & game==25 & uci==0 & matchend!=. & matchend!=2  & match<=4, cluster(sessionun)
reg finalpayoff if strong==1 & separation==1 & game==25 & uci==1 & matchend!=. & matchend!=2  & match<=4 
reg finalpayoff if strong==1 & separation==1 & game==25 & uci==0 & matchend!=. & matchend!=2   & match>4, cluster(sessionun)
reg finalpayoff if strong==1 & separation==1 & game==25 & uci==1 & matchend!=. & matchend!=2   & match>4 

reg finalpayoff if strong==0 & separation==1 & game==25 & uci==0 & matchend!=. & matchend!=2  & match<=4, cluster(sessionun)
reg finalpayoff if strong==0 & separation==1 & game==25 & uci==1 & matchend!=. & matchend!=2  & match<=4 
reg finalpayoff if strong==0 & separation==1 & game==25 & uci==0 & matchend!=. & matchend!=2   & match>4, cluster(sessionun)
reg finalpayoff if strong==0 & separation==1 & game==25 & uci==1 & matchend!=. & matchend!=2   & match>4 

reg finalpayoff uci if strong==1 & separation==0 & game==25 & matchend!=. & matchend!=2   & match<=4, cluster(sessionun)
reg finalpayoff uci if strong==1 & separation==1 & game==25 & matchend!=. & matchend!=2  & match<=4, cluster(sessionun)
reg finalpayoff uci if strong==1 & separation==0 & game==25 & matchend!=. & matchend!=2   & match>4, cluster(sessionun)
reg finalpayoff uci if strong==1 & separation==1 & game==25 & matchend!=. & matchend!=2   & match>4, cluster(sessionun)
 
reg finalpayoff uci if strong==0 & separation==0 & game==25 & matchend!=. & matchend!=2   & match<=4, cluster(sessionun)
reg finalpayoff uci if strong==0 & separation==1 & game==25 & matchend!=. & matchend!=2  & match<=4, cluster(sessionun)
reg finalpayoff uci if strong==0 & separation==0 & game==25 & matchend!=. & matchend!=2  & match>4, cluster(sessionun)
reg finalpayoff uci if strong==0 & separation==1 & game==25 & matchend!=. & matchend!=2   & match>4, cluster(sessionun)

** comparing characteristics of market outcomes between UCSB and UCI
 
** efficiency is higher when the first mover is the weak player
reg efficient firstmoverstrong if separation==0 & matchend!=. & matchend!=2 & index==0   & uci==0 & match>4 , cluster(sessionun)
reg efficient firstmoverstrong if separation==0 & matchend!=. & matchend!=2 & index==0   & uci==1 & match>4  

** payoffs of strong players are higher than those of weak players
reg finalpayoff strong if separation==0 & game==25 & matchend!=2 & matchend!=. & uci==0  & match>4 , cluster(sessionun)
reg finalpayoff strong if separation==0 & game==25 & matchend!=2 & matchend!=. & uci==1   & match>4

reg finalpayoff strong if separation==1 & game==25 & matchend!=2 & matchend!=. & uci==0  & match>4 , cluster(sessionun)
reg finalpayoff strong if separation==1 & game==25 & matchend!=2 & matchend!=. & uci==1  & match>4

 
** efficiency in Exp III is higher than in Exp I
reg efficient separation if matchend!=. & matchend!=2 & index==0 & uci==0  & match>4 , cluster(sessionun)
reg efficient separation if matchend!=. & matchend!=2 & index==0 & uci==1  & match>4

** payoffs of strong players who exit first in efficient outcomes
reg finalpayoff exitfirst  if separation==0 & matchend!=. & matchend!=2   & strong==1 & efficient==1 & uci==0 & match>4, cluster(sessionun)
reg finalpayoff exitfirst  if separation==0 & matchend!=. & matchend!=2   & strong==1 & efficient==1 & uci==1 & match>4


** payoffs of strong players are higher in Exp III than in Exp I
reg finalpayoff separation if matchend!=. & matchend!=2   & strong==1   & uci==0 & match>4, cluster(sessionun)
reg finalpayoff separation if matchend!=. & matchend!=2   & strong==1   & uci==1 & match>4


** payoffs of weak players are higher in Exp III than in Exp I
reg finalpayoff separation if matchend!=. & matchend!=2   & strong==0   & uci==0 & match>4, cluster(sessionun)
reg finalpayoff separation if matchend!=. & matchend!=2   & strong==0   & uci==1 & match>4

** payoffs of strong players in efficient matches are higher in Exp III than in Exp I
reg finalpayoff separation if matchend!=. & matchend!=2   & strong==1 & efficient==1  & uci==0 & match>4, cluster(sessionun)
reg finalpayoff separation if matchend!=. & matchend!=2   & strong==1 & efficient==1  & uci==1 & match>4


** payoffs of weak players in efficient matches are lower in Exp III than in Exp I
reg finalpayoff separation if matchend!=. & matchend!=2   & strong==0 & efficient==1  & uci==0 & match>4, cluster(sessionun)
reg finalpayoff separation if matchend!=. & matchend!=2   & strong==0 & efficient==1  & uci==1 & match>4


************  LEARNING SECTION ***********

** Table 3  

clear
use "/Users/Marina/Dropbox/SUBMITTED/Network Bargaining Experiement/Experiments/DataAnalysis/Structured_2015/Analysis/data_original.dta"

gen finalpayoff = potentialpayoff if matchending!=. & matchending!=2 
gen sessionun = game*100+separation*10 + session*1
gen uniqueid = sessionun*100+clientid

** Efficiency of Final Match

sort sessionun match group round index
gen     totalpayoff = finalpayoff[_n]+finalpayoff[_n+1]+finalpayoff[_n+2]+finalpayoff[_n+3] if matchending!=. & matchending!=2 & index==0

gen     temp = 1 if separation==0 & totalpayoff==40 & matchending!=. & matchending!=2 & index==0
replace temp = 0 if separation==0 & totalpayoff<40 & totalpayoff>0 & matchending!=. & matchending!=2 & index==0
replace temp = 1 if separation==1 & totalpayoff>=37.1 & totalpayoff<=40 & matchending!=. & matchending!=2 & index==0
replace temp = 0 if separation==1 & totalpayoff<37.1 & totalpayoff>0 & matchending!=. & matchending!=2 & index==0

bysort sessionun match groupid: egen efficient = max(temp)
drop temp

** network position 
gen strong = (index==1 | index==3)

* efficiency in Experiments I and III
reg efficient if separation==0 & matchend!=2 & matchend!=. & index==0 & game==15 & match<=4, cluster(sessionun)
reg efficient if separation==0 & matchend!=2 & matchend!=. & index==0 & game==15 & match>4, cluster(sessionun)
reg efficient if separation==0 & matchend!=2 & matchend!=. & index==0 & game==15 , cluster(sessionun)

reg efficient if separation==0 & matchend!=2 & matchend!=. & index==0 & game==25 & match<=4, cluster(sessionun)
reg efficient if separation==0 & matchend!=2 & matchend!=. & index==0 & game==25 & match>4, cluster(sessionun)
reg efficient if separation==0 & matchend!=2 & matchend!=. & index==0 & game==25 , cluster(sessionun)

reg efficient if separation==0 & matchend!=2 & matchend!=. & index==0 & game==30 & match<=4, cluster(sessionun)
reg efficient if separation==0 & matchend!=2 & matchend!=. & index==0 & game==30 & match>4, cluster(sessionun)
reg efficient if separation==0 & matchend!=2 & matchend!=. & index==0 & game==30 , cluster(sessionun)

reg efficient if separation==1 & matchend!=2 & matchend!=. & index==0 & game==15 & match<=4, cluster(sessionun)
reg efficient if separation==1 & matchend!=2 & matchend!=. & index==0 & game==15 & match>4, cluster(sessionun)
reg efficient if separation==1 & matchend!=2 & matchend!=. & index==0 & game==15 , cluster(sessionun)

reg efficient if separation==1 & matchend!=2 & matchend!=. & index==0 & game==25 & match<=4, cluster(sessionun)
reg efficient if separation==1 & matchend!=2 & matchend!=. & index==0 & game==25 & match>4, cluster(sessionun)
reg efficient if separation==1 & matchend!=2 & matchend!=. & index==0 & game==25 , cluster(sessionun)

reg efficient if separation==1 & matchend!=2 & matchend!=. & index==0 & game==30 & match<=4, cluster(sessionun)
reg efficient if separation==1 & matchend!=2 & matchend!=. & index==0 & game==30 & match>4, cluster(sessionun)
reg efficient if separation==1 & matchend!=2 & matchend!=. & index==0 & game==30 , cluster(sessionun)

* payoffs in Experiments I and III
reg finalpayoff if separation==0 & matchend!=2 & matchend!=. & strong==0 & game==15 & match<=4, cluster(sessionun)
reg finalpayoff if separation==0 & matchend!=2 & matchend!=. & strong==0 & game==15 & match>4, cluster(sessionun)
reg finalpayoff if separation==0 & matchend!=2 & matchend!=. & strong==0 & game==15 , cluster(sessionun)
reg finalpayoff if separation==0 & matchend!=2 & matchend!=. & strong==1 & game==15 & match<=4, cluster(sessionun)
reg finalpayoff if separation==0 & matchend!=2 & matchend!=. & strong==1 & game==15 & match>4, cluster(sessionun)
reg finalpayoff if separation==0 & matchend!=2 & matchend!=. & strong==1 & game==15 , cluster(sessionun)

reg finalpayoff if separation==0 & matchend!=2 & matchend!=. & strong==0 & game==25 & match<=4, cluster(sessionun)
reg finalpayoff if separation==0 & matchend!=2 & matchend!=. & strong==0 & game==25 & match>4, cluster(sessionun)
reg finalpayoff if separation==0 & matchend!=2 & matchend!=. & strong==0 & game==25 , cluster(sessionun)
reg finalpayoff if separation==0 & matchend!=2 & matchend!=. & strong==1 & game==25 & match<=4, cluster(sessionun)
reg finalpayoff if separation==0 & matchend!=2 & matchend!=. & strong==1 & game==25 & match>4, cluster(sessionun)
reg finalpayoff if separation==0 & matchend!=2 & matchend!=. & strong==1 & game==25 , cluster(sessionun)

reg finalpayoff if separation==0 & matchend!=2 & matchend!=. & strong==0 & game==30 & match<=4, cluster(sessionun)
reg finalpayoff if separation==0 & matchend!=2 & matchend!=. & strong==0 & game==30 & match>4, cluster(sessionun)
reg finalpayoff if separation==0 & matchend!=2 & matchend!=. & strong==0 & game==30 , cluster(sessionun)
reg finalpayoff if separation==0 & matchend!=2 & matchend!=. & strong==1 & game==30 & match<=4, cluster(sessionun)
reg finalpayoff if separation==0 & matchend!=2 & matchend!=. & strong==1 & game==30 & match>4, cluster(sessionun)
reg finalpayoff if separation==0 & matchend!=2 & matchend!=. & strong==1 & game==30 , cluster(sessionun)

reg finalpayoff if separation==1 & matchend!=2 & matchend!=. & strong==0 & game==15 & match<=4, cluster(sessionun)
reg finalpayoff if separation==1 & matchend!=2 & matchend!=. & strong==0 & game==15 & match>4, cluster(sessionun)
reg finalpayoff if separation==1 & matchend!=2 & matchend!=. & strong==0 & game==15 , cluster(sessionun)
reg finalpayoff if separation==1 & matchend!=2 & matchend!=. & strong==1 & game==15 & match<=4, cluster(sessionun)
reg finalpayoff if separation==1 & matchend!=2 & matchend!=. & strong==1 & game==15 & match>4, cluster(sessionun)
reg finalpayoff if separation==1 & matchend!=2 & matchend!=. & strong==1 & game==15 , cluster(sessionun)

reg finalpayoff if separation==1 & matchend!=2 & matchend!=. & strong==0 & game==25 & match<=4, cluster(sessionun)
reg finalpayoff if separation==1 & matchend!=2 & matchend!=. & strong==0 & game==25 & match>4, cluster(sessionun)
reg finalpayoff if separation==1 & matchend!=2 & matchend!=. & strong==0 & game==25 , cluster(sessionun)
reg finalpayoff if separation==1 & matchend!=2 & matchend!=. & strong==1 & game==25 & match<=4, cluster(sessionun)
reg finalpayoff if separation==1 & matchend!=2 & matchend!=. & strong==1 & game==25 & match>4, cluster(sessionun)
reg finalpayoff if separation==1 & matchend!=2 & matchend!=. & strong==1 & game==25 , cluster(sessionun)

reg finalpayoff if separation==1 & matchend!=2 & matchend!=. & strong==0 & game==30 & match<=4, cluster(sessionun)
reg finalpayoff if separation==1 & matchend!=2 & matchend!=. & strong==0 & game==30 & match>4, cluster(sessionun)
reg finalpayoff if separation==1 & matchend!=2 & matchend!=. & strong==0 & game==30 , cluster(sessionun)
reg finalpayoff if separation==1 & matchend!=2 & matchend!=. & strong==1 & game==30 & match<=4, cluster(sessionun)
reg finalpayoff if separation==1 & matchend!=2 & matchend!=. & strong==1 & game==30 & match>4, cluster(sessionun)
reg finalpayoff if separation==1 & matchend!=2 & matchend!=. & strong==1 & game==30 , cluster(sessionun)

* efficiency and payoffs of players in Experiments II
 
clear
use "/Users/Marina/Dropbox/SUBMITTED/Network Bargaining Experiement/Experiments/DataAnalysis/Unstructured_2016/bargtemp.dta"

gen unique_groupround = session*10+groupid

sort session matchid group index
bysort session matchid group: egen totalpayoff = sum(finalsplit)

** indicator of efficient final allocation
gen efficient = (totalpayoff==40)

** final payoff of players
replace finalsplit = 0 if finalsplit==.

gen strong = (index==1 | index==3)

reg efficient if matchid<=4 & index==0, cluster(session)
reg efficient if matchid>4 & index==0, cluster(session)
reg efficient if index==0, cluster(session)

reg finalsplit if matchid<=4 & strong==0, cluster(session)
reg finalsplit if matchid>4 & strong==0, cluster(session)
reg finalsplit if   strong==0, cluster(session)

reg finalsplit if matchid<=4 & strong==1, cluster(session)
reg finalsplit if matchid>4 & strong==1, cluster(session)
reg finalsplit if   strong==1, cluster(session)


** TABLES 4 and 5


** Experiments I and III, all repetitions 
** (a) significant decrease in efficiency from Game 15 to Game 25 to Game 30 
** (b) players payoffs depend on the network position
** (c) monotonic increase in payoffs between Games 15, 25 and 30 for strong players and opposite for weak players


clear
use "/Users/Marina/Dropbox/SUBMITTED/Network Bargaining Experiement/Experiments/DataAnalysis/Structured_2015/Analysis/data_original.dta"

gen finalpayoff = potentialpayoff if matchending!=. & matchending!=2 
gen sessionun = game*100+separation*10 + session*1
gen uniqueid = sessionun*100+clientid

** efficiency of Final Match

sort sessionun match group round index
gen     totalpayoff = finalpayoff[_n]+finalpayoff[_n+1]+finalpayoff[_n+2]+finalpayoff[_n+3] if matchending!=. & matchending!=2 & index==0

gen     temp = 1 if separation==0 & totalpayoff==40 & matchending!=. & matchending!=2 & index==0
replace temp = 0 if separation==0 & totalpayoff<40 & totalpayoff>0 & matchending!=. & matchending!=2 & index==0
replace temp = 1 if separation==1 & totalpayoff>=37.1 & totalpayoff<=40 & matchending!=. & matchending!=2 & index==0
replace temp = 0 if separation==1 & totalpayoff<37.1 & totalpayoff>0 & matchending!=. & matchending!=2 & index==0

bysort sessionun match groupid: egen efficient = max(temp)
drop temp

** network position 
gen strong = (index==1 | index==3)
gen strong25 = strong * game25
gen strong30 = strong * game30
gen strong15 = strong * game15

** game indicators
gen game15 = (game==15)
gen game30 = (game==30)
gen game25 = (game==25)
 
** efficiency regressions
reg efficient game25 game30 if separation==0 & matchend!=. & matchend!=2 & index==0  , cluster(sessionun)
test game25 game30
test game30 = game25
test _cons + game25 = 0.72
test _cons + game30 = 0.50

reg efficient game25 game30 if separation==1 & matchend!=. & matchend!=2 & index==0  , cluster(sessionun)
test game25 game30
test game30 = game25

** payoffs regressions
reg finalpayoff game25 game30 strong15 strong25 strong30 if separation==0 & matchend!=. & matchend!=2   , cluster(sessionun)
test game25 = game30
test game25 + strong25 = game30 + strong30

reg finalpayoff game25 game30 strong15 strong25 strong30 if separation==1 & matchend!=. & matchend!=2   , cluster(sessionun)
test game25 = game30
test game25 + strong25 = game30 + strong30

** comparing efficiency and players' payoffs in first and last repetitions of the experiment
gen last5 = (match>4)
gen last5game15 = last5*game15
gen last5game25 = last5*game25
gen last5game30 = last5*game30

reg efficient   game25 game30 last5game15 last5game25 last5game30 if separation==0 & index==0  & matchend!=2 & matchend!=. , cluster(sessionun)
reg finalpayoff game25 game30 last5game15 last5game25 last5game30 if separation==0 & strong==1 & matchend!=2 & matchend!=. , cluster(sessionun)
reg finalpayoff game25 game30 last5game15 last5game25 last5game30 if separation==0 & strong==0 & matchend!=2 & matchend!=. , cluster(sessionun)

reg efficient   game25 game30 last5game15 last5game25 last5game30 if separation==1 & index==0  & matchend!=2 & matchend!=. , cluster(sessionun)
reg finalpayoff game25 game30 last5game15 last5game25 last5game30 if separation==1 & strong==1 & matchend!=2 & matchend!=. , cluster(sessionun)
reg finalpayoff game25 game30 last5game15 last5game25 last5game30 if separation==1 & strong==0 & matchend!=2 & matchend!=. , cluster(sessionun)

